You are viewing a plain text version of this content. The canonical link for it is here.
Posted to scm@geronimo.apache.org by am...@apache.org on 2006/04/14 08:30:51 UTC

svn commit: r394030 [2/3] - in /geronimo/branches/1.1: applications/console-core/src/java/org/apache/geronimo/console/util/ applications/console-framework/src/webapp/WEB-INF/data/ applications/console-standard/src/java/org/apache/geronimo/console/ appl...

Modified: geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/view/keystore/index.jsp
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/view/keystore/index.jsp?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/view/keystore/index.jsp (original)
+++ geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/view/keystore/index.jsp Thu Apr 13 23:30:38 2006
@@ -53,21 +53,31 @@
         <c:when test="${keystore.locked}">
           <a href="<portlet:actionURL portletMode="view">
             <portlet:param name="mode" value="unlockEdit-before" />
-            <portlet:param name="id" value="${keystore.instance.keystoreName}" />
+            <portlet:param name="keystore" value="${keystore.instance.keystoreName}" />
             </portlet:actionURL>"><img src="<%=consoleServletPath%>/../images/ico_lock_16x16.gif" alt="Locked" /></a>
         </c:when>
         <c:otherwise>
-          <img src="<%=consoleServletPath%>/../images/ico_unlock3_16x16.gif" alt="Unlocked" />
+          <a href="<portlet:actionURL portletMode="view">
+            <portlet:param name="mode" value="lockEdit-before" />
+            <portlet:param name="keystore" value="${keystore.instance.keystoreName}" />
+            </portlet:actionURL>"><img src="<%=consoleServletPath%>/../images/ico_unlock3_16x16.gif" alt="Unlocked" /></a>
         </c:otherwise>
       </c:choose>
     </td>
     <td>
       <c:choose>
         <c:when test="${keystore.instance.keystoreLocked}">
-          <img src="<%=consoleServletPath%>/../images/ico_lock_16x16.gif" alt="Locked" />
+          <a href="<portlet:actionURL portletMode="view">
+            <portlet:param name="mode" value="unlockKeystore-before" />
+            <portlet:param name="keystore" value="${keystore.instance.keystoreName}" />
+            </portlet:actionURL>"><img src="<%=consoleServletPath%>/../images/ico_lock_16x16.gif" alt="Locked" /></a>
         </c:when>
         <c:otherwise>
-          <img src="<%=consoleServletPath%>/../images/ico_unlock3_16x16.gif" alt="Unlocked" />
+          <a href="<portlet:actionURL portletMode="view">
+            <portlet:param name="mode" value="lockKeystore-before" />
+            <portlet:param name="keystore" value="${keystore.instance.keystoreName}" />
+            </portlet:actionURL>"><img src="<%=consoleServletPath%>/../images/ico_unlock3_16x16.gif" alt="Unlocked" /></a>
+            ${keys[keystore.instance.keystoreName]}
         </c:otherwise>
       </c:choose>
     </td>

Modified: geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/view/keystore/unlockKeystore.jsp
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/view/keystore/unlockKeystore.jsp?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/view/keystore/unlockKeystore.jsp (original)
+++ geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/view/keystore/unlockKeystore.jsp Thu Apr 13 23:30:38 2006
@@ -4,11 +4,24 @@
 <portlet:defineObjects/>
 
 <form name="<portlet:namespace/>KeystoreForm" action="<portlet:actionURL/>">
-    <input type="hidden" name="keystore" value="${id}" />
-    <input type="hidden" name="mode" value="unlockEdit-after" />
+    <input type="hidden" name="keystore" value="${keystore}" />
+    <input type="hidden" name="mode" value="${mode}-after" />
     <b>Enter keystore password:</b>
     <input type="password" name="password" size="20" maxlength="200" />
     <br />
+
+    <c:if test="${mode eq 'unlockKeystore' && !empty keys}">
+        <b>Unlock Private Key:</b>
+        <select name="keyAlias">
+            <c:forEach var="alias" items="${keys}">
+                <option>${alias}</option>
+            </c:forEach>
+        </select>
+        Password:
+        <input type="password" name="keyPassword" size="20" maxlength="200" />
+        <br />
+    </c:if>
+
     <input type="submit" value="Unlock Keystore" />
 </form>
 

Modified: geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/view/webmanager/connector/editHTTPS.jsp
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/view/webmanager/connector/editHTTPS.jsp?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/view/webmanager/connector/editHTTPS.jsp (original)
+++ geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/view/webmanager/connector/editHTTPS.jsp Thu Apr 13 23:30:38 2006
@@ -88,6 +88,46 @@
     <th colspan="2"><div align="left">SSL Settings</div></th>
   </tr>
 
+<!-- ====================================== JETTY ONLY ====================================== -->
+<c:if test="${server eq 'jetty'}">
+    <!-- Key Store Field -->
+      <tr>
+        <td><div align="right">Key Store: </div></td>
+        <td>
+          <select name="unlockKeyStore">
+              <c:forEach var="store" items="${keyStores}">
+                  <option>${store}</option>
+              </c:forEach>
+          </select>
+        </td>
+      </tr>
+      <tr>
+        <td><div align="right"></div></td>
+        <td>The keystore to use for accessing the server's private key</td>
+      </tr>
+
+    <!-- Trust Store Field -->
+      <tr>
+        <td><div align="right">Trust Store: </div></td>
+        <td>
+          <select name="unlockTrustStore">
+              <option />
+              <c:forEach var="store" items="${trustStores}">
+                  <option>${store}</option>
+              </c:forEach>
+          </select>
+        </td>
+      </tr>
+      <tr>
+        <td><div align="right"></div></td>
+        <td>The keystore to use for accessing the server's private key</td>
+      </tr>
+
+</c:if>
+
+
+<!-- ========================== TOMCAT ONLY ====================================== -->
+<c:if test="${server eq 'tomcat'}">
 <!-- Keystore File Field -->
   <tr>
     <td><div align="right">Keystore File: </div></td>
@@ -116,41 +156,23 @@
       this empty if you don't want to change the current password.</c:if></td>
   </tr>
 
-<!-- Key Password Field (Jetty only) -->
-<c:if test="${server eq 'jetty'}">
-  <tr>
-    <td><div align="right"><c:if test="${mode eq 'save'}">Change </c:if>Server Key Password: </div></td>
-    <td>
-      <input name="privateKeyPassword" type="password" size="10">
-	</td>
-  </tr>
-  <tr>
-    <td><div align="right"></div></td>
-    <td><c:choose><c:when test="${mode eq 'save'}">Change</c:when><c:otherwise>Set</c:otherwise></c:choose>
-      the password used to access the private key in the keystore.<c:if test="${mode eq 'save'}">  Leave
-      this empty if you don't want to change the current password.</c:if></td>
-  </tr>
-</c:if>
-
-<!-- Keystore Type Field -->
-  <tr>
-    <td><div align="right">Keystore Type: </div></td>
-    <td>
-      <select name="keystoreType">
-        <option<c:if test="${keystoreType eq 'JKS' || logLevel eq ''}"> selected</c:if>>JKS</option>
-        <option<c:if test="${keystoreType eq 'PKCS12'}"> selected</c:if>>PKCS12</option>
-      </select>
-	</td>
-  </tr>
-  <tr>
-    <td><div align="right"></div></td>
-    <td><c:choose><c:when test="${mode eq 'save'}">Change</c:when><c:otherwise>Set</c:otherwise></c:choose>
-      the keystore type.  There is normally no reason not to use the default (<tt>JKS</tt>).</td>
-  </tr>
+    <!-- Keystore Type Field -->
+      <tr>
+        <td><div align="right">Keystore Type: </div></td>
+        <td>
+          <select name="keystoreType">
+            <option<c:if test="${keystoreType eq 'JKS' || logLevel eq ''}"> selected</c:if>>JKS</option>
+            <option<c:if test="${keystoreType eq 'PKCS12'}"> selected</c:if>>PKCS12</option>
+          </select>
+        </td>
+      </tr>
+      <tr>
+        <td><div align="right"></div></td>
+        <td><c:choose><c:when test="${mode eq 'save'}">Change</c:when><c:otherwise>Set</c:otherwise></c:choose>
+          the keystore type.  There is normally no reason not to use the default (<tt>JKS</tt>).</td>
+      </tr>
 
-<!-- Trust material (Tomcat only) -->
-<c:if test="${server eq 'tomcat'}">
-<!-- Truststore File Field -->
+  <!-- Truststore File Field -->
   <tr>
     <td><div align="right">Truststore File: </div></td>
     <td>

Modified: geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/web.xml
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/web.xml?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/web.xml (original)
+++ geronimo/branches/1.1/applications/console-standard/src/webapp/WEB-INF/web.xml Thu Apr 13 23:30:38 2006
@@ -727,6 +727,20 @@
             <param-value>console-standard.RunSQL</param-value>
         </init-param>
     </servlet>
+    <servlet>
+        <description>Automated generated Portlet Wrapper</description>
+        <display-name>Pluto Wrapper for CAR Import/Export Portlet</display-name>
+        <servlet-name>ImportExport</servlet-name>
+        <servlet-class>org.apache.pluto.core.PortletServlet</servlet-class>
+        <init-param>
+            <param-name>portlet-class</param-name>
+            <param-value>org.apache.geronimo.console.car.ImportExportPortlet</param-value>
+        </init-param>
+        <init-param>
+            <param-name>portlet-guid</param-name>
+            <param-value>console-standard.ImportExport</param-value>
+        </init-param>
+    </servlet>
 
 
 
@@ -739,11 +753,29 @@
      <param-value>true</param-value>
   </init-param>
 </servlet>
+<servlet>
+  <display-name>CAR Export Servlet</display-name>
+  <servlet-name>car-export</servlet-name>
+  <servlet-class>org.apache.geronimo.console.car.CARExportServlet</servlet-class>
+</servlet>
+<servlet>
+  <display-name>Geronimo as Maven Repo Servlet</display-name>
+  <servlet-name>maven-repo</servlet-name>
+  <servlet-class>org.apache.geronimo.console.car.GeronimoAsMavenServlet</servlet-class>
+</servlet>
 
 <servlet-mapping>
   <servlet-name>dwr-invoker</servlet-name>
   <url-pattern>/dwr/*</url-pattern>
 </servlet-mapping>
+<servlet-mapping>
+  <servlet-name>car-export</servlet-name>
+  <url-pattern>/car-export</url-pattern>
+</servlet-mapping>
+<servlet-mapping>
+  <servlet-name>maven-repo</servlet-name>
+  <url-pattern>/maven-repo/*</url-pattern>
+</servlet-mapping>
 
 
 
@@ -960,6 +992,10 @@
     <servlet-mapping>
         <servlet-name>RunSQL</servlet-name>
         <url-pattern>/RunSQL/*</url-pattern>
+    </servlet-mapping>
+    <servlet-mapping>
+        <servlet-name>ImportExport</servlet-name>
+        <url-pattern>/ImportExport/*</url-pattern>
     </servlet-mapping>
 
 <!-- org.apache.geronimo.console.core.securitymanager.SecurityRealmsPortlet

Modified: geronimo/branches/1.1/assemblies/j2ee-installer/src/var/config/config.xml
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/assemblies/j2ee-installer/src/var/config/config.xml?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/assemblies/j2ee-installer/src/var/config/config.xml (original)
+++ geronimo/branches/1.1/assemblies/j2ee-installer/src/var/config/config.xml Thu Apr 13 23:30:38 2006
@@ -30,6 +30,15 @@
         <gbean name="JMXService">
             <attribute name="url">service:jmx:rmi://${PlanServerHostname}:${PlanJMXPort}/jndi/rmi://${PlanServerHostname}:${PlanNamingPort}/JMXConnector</attribute>
         </gbean>
+        <gbean name="geronimo.server:J2EEApplication=null,J2EEModule=geronimo/j2ee-security/1.2-SNAPSHOT/car,J2EEServer=geronimo,j2eeType=Keystore,name=geronimo-default" gbeanInfo="org.apache.geronimo.security.keystore.FileKeystoreInstance">
+            <attribute name="keystoreName">geronimo-default</attribute>
+            <attribute name="keystorePassword">{Simple}rO0ABXNyABlqYXZheC5jcnlwdG8uU2VhbGVkT2JqZWN0PjY9psO3VHACAARbAA1lbmNvZGVkUGFyYW1zdAACW0JbABBlbmNyeXB0ZWRDb250ZW50cQB+AAFMAAlwYXJhbXNBbGd0ABJMamF2YS9sYW5nL1N0cmluZztMAAdzZWFsQWxncQB+AAJ4cHB1cgACW0Ks8xf4BghU4AIAAHhwAAAAEArVToThqcjvbXFD5C2uUmpwdAADQUVT</attribute>
+            <attribute name="keyPasswords">{Simple}rO0ABXNyABlqYXZheC5jcnlwdG8uU2VhbGVkT2JqZWN0PjY9psO3VHACAARbAA1lbmNvZGVkUGFyYW1zdAACW0JbABBlbmNyeXB0ZWRDb250ZW50cQB+AAFMAAlwYXJhbXNBbGd0ABJMamF2YS9sYW5nL1N0cmluZztMAAdzZWFsQWxncQB+AAJ4cHB1cgACW0Ks8xf4BghU4AIAAHhwAAAAIGdUCEvsw3HNoD82HNiAiTo5m8E/c8pnljroPhWCnB89cHQAA0FFUw==</attribute>
+            <attribute name="keystorePath">var/security/keystores/geronimo-default</attribute>
+            <reference name="ServerInfo">
+                <pattern><gbean-name>geronimo.server:J2EEApplication=null,J2EEModule=geronimo/j2ee-system/1.2-SNAPSHOT/car,J2EEServer=geronimo,j2eeType=GBean,name=ServerInfo</gbean-name></pattern>
+            </reference>
+        </gbean>
     </configuration>
     <configuration name="geronimo/j2ee-corba/${pom.currentVersion}/car" load="${CORBA.Features.enable}">
         <gbean name="NameServer">

Modified: geronimo/branches/1.1/assemblies/j2ee-jetty-server/src/var/config/config.xml
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/assemblies/j2ee-jetty-server/src/var/config/config.xml?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/assemblies/j2ee-jetty-server/src/var/config/config.xml (original)
+++ geronimo/branches/1.1/assemblies/j2ee-jetty-server/src/var/config/config.xml Thu Apr 13 23:30:38 2006
@@ -30,6 +30,15 @@
         <gbean name="JMXService">
             <attribute name="url">service:jmx:rmi://${PlanServerHostname}:${PlanJMXPort}/jndi/rmi://${PlanServerHostname}:${PlanNamingPort}/JMXConnector</attribute>
         </gbean>
+        <gbean name="geronimo.server:J2EEApplication=null,J2EEModule=geronimo/j2ee-security/1.2-SNAPSHOT/car,J2EEServer=geronimo,j2eeType=Keystore,name=geronimo-default" gbeanInfo="org.apache.geronimo.security.keystore.FileKeystoreInstance">
+            <attribute name="keystoreName">geronimo-default</attribute>
+            <attribute name="keystorePassword">{Simple}rO0ABXNyABlqYXZheC5jcnlwdG8uU2VhbGVkT2JqZWN0PjY9psO3VHACAARbAA1lbmNvZGVkUGFyYW1zdAACW0JbABBlbmNyeXB0ZWRDb250ZW50cQB+AAFMAAlwYXJhbXNBbGd0ABJMamF2YS9sYW5nL1N0cmluZztMAAdzZWFsQWxncQB+AAJ4cHB1cgACW0Ks8xf4BghU4AIAAHhwAAAAEArVToThqcjvbXFD5C2uUmpwdAADQUVT</attribute>
+            <attribute name="keyPasswords">{Simple}rO0ABXNyABlqYXZheC5jcnlwdG8uU2VhbGVkT2JqZWN0PjY9psO3VHACAARbAA1lbmNvZGVkUGFyYW1zdAACW0JbABBlbmNyeXB0ZWRDb250ZW50cQB+AAFMAAlwYXJhbXNBbGd0ABJMamF2YS9sYW5nL1N0cmluZztMAAdzZWFsQWxncQB+AAJ4cHB1cgACW0Ks8xf4BghU4AIAAHhwAAAAIGdUCEvsw3HNoD82HNiAiTo5m8E/c8pnljroPhWCnB89cHQAA0FFUw==</attribute>
+            <attribute name="keystorePath">var/security/keystores/geronimo-default</attribute>
+            <reference name="ServerInfo">
+                <pattern><gbean-name>geronimo.server:J2EEApplication=null,J2EEModule=geronimo/j2ee-system/1.2-SNAPSHOT/car,J2EEServer=geronimo,j2eeType=GBean,name=ServerInfo</gbean-name></pattern>
+            </reference>
+        </gbean>
     </configuration>
     <configuration name="geronimo/j2ee-corba/${pom.currentVersion}/car" load="false">
         <gbean name="NameServer">
@@ -62,7 +71,7 @@
             <attribute name="port">${PlanLdapPort}</attribute>
         </gbean>
     </configuration>
-    <configuration name="geronimo/ldap-realm/${pom.currentVersion}/car"/>
+    <configuration name="geronimo/ldap-realm/${pom.currentVersion}/car" load="false"/>
     <configuration name="geronimo/jetty/${pom.currentVersion}/car">
         <gbean name="JettyWebConnector">
             <attribute name="host">${PlanServerHostname}</attribute>
@@ -91,13 +100,13 @@
     </configuration>
     <configuration name="geronimo/jetty-deployer/${pom.currentVersion}/car"/>
     <configuration name="geronimo/welcome-jetty/${pom.currentVersion}/car"/>
-    <configuration name="geronimo/ldap-demo-jetty/${pom.currentVersion}/car"/>
-    <configuration name="geronimo/servlets-examples-jetty/${pom.currentVersion}/car"/>
-    <configuration name="geronimo/jsp-examples-jetty/${pom.currentVersion}/car"/>
+    <configuration name="geronimo/ldap-demo-jetty/${pom.currentVersion}/car" load="false"/>
+    <configuration name="geronimo/servlets-examples-jetty/${pom.currentVersion}/car" load="false"/>
+    <configuration name="geronimo/jsp-examples-jetty/${pom.currentVersion}/car" load="false"/>
     <configuration name="geronimo/webconsole-jetty/${pom.currentVersion}/car"/>
-    <configuration name="geronimo/uddi-jetty/${pom.currentVersion}/car"/>
-    <configuration name="geronimo/jmxdebug-jetty/${pom.currentVersion}/car"/>
-    <configuration name="geronimo/daytrader-derby-jetty/${pom.currentVersion}/car"/>
-    <configuration name="geronimo/remote-deploy-jetty/${pom.currentVersion}/car"/>
-    <configuration name="geronimo/hot-deployer/${pom.currentVersion}/car" />
+    <configuration name="geronimo/uddi-jetty/${pom.currentVersion}/car" load="false"/>
+    <configuration name="geronimo/jmxdebug-jetty/${pom.currentVersion}/car" load="false"/>
+    <configuration name="geronimo/daytrader-derby-jetty/${pom.currentVersion}/car" load="false"/>
+    <configuration name="geronimo/remote-deploy-jetty/${pom.currentVersion}/car" load="false"/>
+    <configuration name="geronimo/hot-deployer/${pom.currentVersion}/car"  load="false"/>
 </attributes>

Modified: geronimo/branches/1.1/assemblies/j2ee-tomcat-server/src/var/config/config.xml
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/assemblies/j2ee-tomcat-server/src/var/config/config.xml?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/assemblies/j2ee-tomcat-server/src/var/config/config.xml (original)
+++ geronimo/branches/1.1/assemblies/j2ee-tomcat-server/src/var/config/config.xml Thu Apr 13 23:30:38 2006
@@ -30,6 +30,15 @@
         <gbean name="JMXService">
             <attribute name="url">service:jmx:rmi://${PlanServerHostname}:${PlanJMXPort}/jndi/rmi://${PlanServerHostname}:${PlanNamingPort}/JMXConnector</attribute>
         </gbean>
+        <gbean name="geronimo.server:J2EEApplication=null,J2EEModule=geronimo/j2ee-security/1.2-SNAPSHOT/car,J2EEServer=geronimo,j2eeType=Keystore,name=geronimo-default" gbeanInfo="org.apache.geronimo.security.keystore.FileKeystoreInstance">
+            <attribute name="keystoreName">geronimo-default</attribute>
+            <attribute name="keystorePassword">{Simple}rO0ABXNyABlqYXZheC5jcnlwdG8uU2VhbGVkT2JqZWN0PjY9psO3VHACAARbAA1lbmNvZGVkUGFyYW1zdAACW0JbABBlbmNyeXB0ZWRDb250ZW50cQB+AAFMAAlwYXJhbXNBbGd0ABJMamF2YS9sYW5nL1N0cmluZztMAAdzZWFsQWxncQB+AAJ4cHB1cgACW0Ks8xf4BghU4AIAAHhwAAAAEArVToThqcjvbXFD5C2uUmpwdAADQUVT</attribute>
+            <attribute name="keyPasswords">{Simple}rO0ABXNyABlqYXZheC5jcnlwdG8uU2VhbGVkT2JqZWN0PjY9psO3VHACAARbAA1lbmNvZGVkUGFyYW1zdAACW0JbABBlbmNyeXB0ZWRDb250ZW50cQB+AAFMAAlwYXJhbXNBbGd0ABJMamF2YS9sYW5nL1N0cmluZztMAAdzZWFsQWxncQB+AAJ4cHB1cgACW0Ks8xf4BghU4AIAAHhwAAAAIGdUCEvsw3HNoD82HNiAiTo5m8E/c8pnljroPhWCnB89cHQAA0FFUw==</attribute>
+            <attribute name="keystorePath">var/security/keystores/geronimo-default</attribute>
+            <reference name="ServerInfo">
+                <pattern><gbean-name>geronimo.server:J2EEApplication=null,J2EEModule=geronimo/j2ee-system/1.2-SNAPSHOT/car,J2EEServer=geronimo,j2eeType=GBean,name=ServerInfo</gbean-name></pattern>
+            </reference>
+        </gbean>
     </configuration>
     <configuration name="geronimo/j2ee-corba/${pom.currentVersion}/car" load="false">
         <gbean name="NameServer">

Modified: geronimo/branches/1.1/configs/client-system/src/plan/plan.xml
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/configs/client-system/src/plan/plan.xml?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/configs/client-system/src/plan/plan.xml (original)
+++ geronimo/branches/1.1/configs/client-system/src/plan/plan.xml Thu Apr 13 23:30:38 2006
@@ -74,8 +74,8 @@
             javax.net.ssl.trustStorePassword=secret
         </attribute>
         <attribute name="systemPathProperties">
-            javax.net.ssl.keyStore=var/security/keystore
-            javax.net.ssl.trustStore=var/security/keystore
+            javax.net.ssl.keyStore=var/security/keystores/geronimo-default
+            javax.net.ssl.trustStore=var/security/keystores/geronimo-default
         </attribute>
         <reference name="ServerInfo">
             <name>ServerInfo</name>

Modified: geronimo/branches/1.1/configs/j2ee-system/src/plan/plan.xml
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/configs/j2ee-system/src/plan/plan.xml?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/configs/j2ee-system/src/plan/plan.xml (original)
+++ geronimo/branches/1.1/configs/j2ee-system/src/plan/plan.xml Thu Apr 13 23:30:38 2006
@@ -90,6 +90,19 @@
     </reference>
   </gbean>
 
+  <!-- Configuration Installer -->
+  <gbean name="ConfigurationInstaller" class="org.apache.geronimo.system.configuration.ConfigInstallerGBean">
+    <reference name="Repository">
+      <name>Repository</name>
+    </reference>
+    <reference name="ConfigStore">
+      <name>Local</name>
+    </reference>
+    <reference name="ConfigManager">
+      <name>ConfigurationManager</name>
+    </reference>
+  </gbean>
+
   <!-- Logging service -->
   <gbean name="Logger" class="org.apache.geronimo.system.logging.log4j.Log4jService">
     <attribute name="configFileName">var/log/server-log4j.properties</attribute>

Modified: geronimo/branches/1.1/configs/jetty/project.xml
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/configs/jetty/project.xml?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/configs/jetty/project.xml (original)
+++ geronimo/branches/1.1/configs/jetty/project.xml Thu Apr 13 23:30:38 2006
@@ -41,7 +41,7 @@
         <!-- parent config -->
         <dependency>
             <groupId>geronimo</groupId>
-            <artifactId>rmi-naming</artifactId>
+            <artifactId>j2ee-security</artifactId>
             <version>${geronimo_version}</version>
             <type>car</type>
             <properties>

Modified: geronimo/branches/1.1/configs/jetty/src/plan/plan.xml
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/configs/jetty/src/plan/plan.xml?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/configs/jetty/src/plan/plan.xml (original)
+++ geronimo/branches/1.1/configs/jetty/src/plan/plan.xml Thu Apr 13 23:30:38 2006
@@ -88,10 +88,9 @@
     <gbean name="JettySSLConnector" class="org.apache.geronimo.jetty.connector.HTTPSConnector">
         <attribute name="host">${PlanServerHostname}</attribute>
         <attribute name="port">${PlanHTTPSPort}</attribute>
-        <attribute name="keystoreFileName">var/security/keystore</attribute>
-        <attribute name="keystoreType">JKS</attribute>
-        <attribute name="keystorePassword">secret</attribute>
-        <attribute name="keyPassword">secret</attribute>
+        <attribute name="keyStore">geronimo-default</attribute>
+        <attribute name="keyAlias">geronimo</attribute>
+        <attribute name="trustStore">geronimo-default</attribute>
         <attribute name="clientAuthRequired">false</attribute>
         <attribute name="algorithm">Default</attribute>
         <attribute name="secureProtocol">TLS</attribute>
@@ -100,8 +99,8 @@
         <reference name="JettyContainer">
             <name>JettyWebContainer</name>
         </reference>
-        <reference name="ServerInfo">
-            <name>ServerInfo</name>
+        <reference name="KeystoreManager">
+            <name>KeystoreManager</name>
         </reference>
     </gbean>
 

Modified: geronimo/branches/1.1/configs/rmi-naming/src/plan/plan.xml
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/configs/rmi-naming/src/plan/plan.xml?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/configs/rmi-naming/src/plan/plan.xml (original)
+++ geronimo/branches/1.1/configs/rmi-naming/src/plan/plan.xml Thu Apr 13 23:30:38 2006
@@ -45,8 +45,8 @@
             javax.net.ssl.trustStorePassword=secret
         </attribute>
         <attribute name="systemPathProperties">
-            javax.net.ssl.keyStore=var/security/keystore
-            javax.net.ssl.trustStore=var/security/keystore
+            javax.net.ssl.keyStore=var/security/keystores/geronimo-default
+            javax.net.ssl.trustStore=var/security/keystores/geronimo-default
         </attribute>
         <reference name="ServerInfo">
             <name>ServerInfo</name>

Modified: geronimo/branches/1.1/configs/tomcat/src/plan/plan.xml
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/configs/tomcat/src/plan/plan.xml?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/configs/tomcat/src/plan/plan.xml (original)
+++ geronimo/branches/1.1/configs/tomcat/src/plan/plan.xml Thu Apr 13 23:30:38 2006
@@ -100,7 +100,7 @@
         <attribute name="clientAuthRequired">false</attribute>
         <attribute name="algorithm">Default</attribute>
         <attribute name="secureProtocol">TLS</attribute>
-        <attribute name="keystoreFileName">var/security/keystore</attribute>
+        <attribute name="keystoreFileName">var/security/keystores/geronimo-default</attribute>
         <attribute name="keystorePassword">secret</attribute>
         <reference name="TomcatContainer">
             <name>TomcatWebContainer</name>

Modified: geronimo/branches/1.1/modules/connector-builder/src/test/org/apache/geronimo/connector/deployment/ConnectorModuleBuilderTest.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/connector-builder/src/test/org/apache/geronimo/connector/deployment/ConnectorModuleBuilderTest.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/connector-builder/src/test/org/apache/geronimo/connector/deployment/ConnectorModuleBuilderTest.java (original)
+++ geronimo/branches/1.1/modules/connector-builder/src/test/org/apache/geronimo/connector/deployment/ConnectorModuleBuilderTest.java Thu Apr 13 23:30:38 2006
@@ -68,6 +68,7 @@
 import org.apache.geronimo.kernel.config.EditableKernelConfigurationManager;
 import org.apache.geronimo.kernel.config.InvalidConfigException;
 import org.apache.geronimo.kernel.config.NoSuchConfigException;
+import org.apache.geronimo.kernel.config.NullConfigurationStore;
 import org.apache.geronimo.kernel.management.State;
 import org.apache.geronimo.kernel.repository.Artifact;
 import org.apache.geronimo.kernel.repository.DefaultArtifactManager;
@@ -584,7 +585,7 @@
         }
     }
 
-    public static class MockConfigStore implements ConfigurationStore {
+    public static class MockConfigStore extends NullConfigurationStore {
         private Map configs = new HashMap();
 
         URL baseURL;
@@ -618,18 +619,6 @@
 
         public boolean containsConfiguration(Artifact configID) {
             return true;
-        }
-
-        public String getObjectName() {
-            return null;
-        }
-
-        public AbstractName getAbstractName() {
-            return null;
-        }
-
-        public List listConfigurations() {
-            return null;
         }
 
         public File createNewConfigurationDir(Artifact configId) {

Modified: geronimo/branches/1.1/modules/deploy-jsr88/project.xml
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/deploy-jsr88/project.xml?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/deploy-jsr88/project.xml (original)
+++ geronimo/branches/1.1/modules/deploy-jsr88/project.xml Thu Apr 13 23:30:38 2006
@@ -92,6 +92,12 @@
 
         <dependency>
             <groupId>geronimo</groupId>
+            <artifactId>geronimo-system</artifactId>
+            <version>${pom.currentVersion}</version>
+        </dependency>
+
+        <dependency>
+            <groupId>geronimo</groupId>
             <artifactId>geronimo-util</artifactId>
             <version>${pom.currentVersion}</version>
         </dependency>

Added: geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/GeronimoDeploymentManager.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/GeronimoDeploymentManager.java?rev=394030&view=auto
==============================================================================
--- geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/GeronimoDeploymentManager.java (added)
+++ geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/GeronimoDeploymentManager.java Thu Apr 13 23:30:38 2006
@@ -0,0 +1,29 @@
+/**
+ *
+ * Copyright 2005 The Apache Software Foundation
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
+package org.apache.geronimo.deployment.plugin;
+
+import org.apache.geronimo.system.configuration.ConfigurationInstaller;
+
+import javax.enterprise.deploy.spi.DeploymentManager;
+
+/**
+ * Enhanced features for Geronimo deployment manager
+ *
+ * @version $Rev: 46019 $ $Date: 2004-09-14 05:56:06 -0400 (Tue, 14 Sep 2004) $
+ */
+public interface GeronimoDeploymentManager extends DeploymentManager, ConfigurationInstaller {
+}

Propchange: geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/GeronimoDeploymentManager.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/TargetImpl.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/TargetImpl.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/TargetImpl.java (original)
+++ geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/TargetImpl.java Thu Apr 13 23:30:38 2006
@@ -20,6 +20,7 @@
 import javax.enterprise.deploy.spi.Target;
 import javax.management.ObjectName;
 import java.io.Serializable;
+import org.apache.geronimo.gbean.AbstractName;
 
 /**
  *
@@ -27,15 +28,15 @@
  * @version $Rev$ $Date$
  */
 public class TargetImpl implements Target, Serializable {
-    private final ObjectName name;
+    private final AbstractName name;
     private final String description;
 
-    public TargetImpl(ObjectName name, String description) {
+    public TargetImpl(AbstractName name, String description) {
         this.name = name;
         this.description = description;
     }
 
-    public ObjectName getObjectName() {
+    public AbstractName getAbstractName() {
         return name;
     }
 

Modified: geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/jmx/JMXDeploymentManager.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/jmx/JMXDeploymentManager.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/jmx/JMXDeploymentManager.java (original)
+++ geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/jmx/JMXDeploymentManager.java Thu Apr 13 23:30:38 2006
@@ -16,6 +16,23 @@
  */
 package org.apache.geronimo.deployment.plugin.jmx;
 
+import java.io.File;
+import java.io.InputStream;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Locale;
+import javax.enterprise.deploy.model.DeployableObject;
+import javax.enterprise.deploy.shared.DConfigBeanVersionType;
+import javax.enterprise.deploy.shared.ModuleType;
+import javax.enterprise.deploy.spi.DeploymentConfiguration;
+import javax.enterprise.deploy.spi.DeploymentManager;
+import javax.enterprise.deploy.spi.Target;
+import javax.enterprise.deploy.spi.TargetModuleID;
+import javax.enterprise.deploy.spi.exceptions.DConfigBeanVersionUnsupportedException;
+import javax.enterprise.deploy.spi.exceptions.InvalidModuleException;
+import javax.enterprise.deploy.spi.exceptions.TargetException;
+import javax.enterprise.deploy.spi.status.ProgressObject;
+import javax.management.MalformedObjectNameException;
 import org.apache.geronimo.connector.deployment.RARConfigurer;
 import org.apache.geronimo.deployment.plugin.TargetImpl;
 import org.apache.geronimo.deployment.plugin.TargetModuleIDImpl;
@@ -25,6 +42,7 @@
 import org.apache.geronimo.deployment.plugin.local.StartCommand;
 import org.apache.geronimo.deployment.plugin.local.StopCommand;
 import org.apache.geronimo.deployment.plugin.local.UndeployCommand;
+import org.apache.geronimo.gbean.AbstractName;
 import org.apache.geronimo.kernel.Kernel;
 import org.apache.geronimo.kernel.config.ConfigurationInfo;
 import org.apache.geronimo.kernel.config.ConfigurationManager;
@@ -34,25 +52,6 @@
 import org.apache.geronimo.kernel.management.State;
 import org.apache.geronimo.web.deployment.WARConfigurer;
 
-import javax.enterprise.deploy.model.DeployableObject;
-import javax.enterprise.deploy.shared.DConfigBeanVersionType;
-import javax.enterprise.deploy.shared.ModuleType;
-import javax.enterprise.deploy.spi.DeploymentConfiguration;
-import javax.enterprise.deploy.spi.DeploymentManager;
-import javax.enterprise.deploy.spi.Target;
-import javax.enterprise.deploy.spi.TargetModuleID;
-import javax.enterprise.deploy.spi.exceptions.DConfigBeanVersionUnsupportedException;
-import javax.enterprise.deploy.spi.exceptions.InvalidModuleException;
-import javax.enterprise.deploy.spi.exceptions.TargetException;
-import javax.enterprise.deploy.spi.status.ProgressObject;
-import javax.management.MalformedObjectNameException;
-import javax.management.ObjectName;
-import java.io.File;
-import java.io.InputStream;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Locale;
-
 
 /**
  * @version $Rev$ $Date$
@@ -95,7 +94,7 @@
 
         Target[] targets = new Target[stores.size()];
         for (int i = 0; i < stores.size(); i++) {
-            ObjectName storeName = (ObjectName) stores.get(i);
+            AbstractName storeName = (AbstractName) stores.get(i);
             targets[i] = new TargetImpl(storeName, null);
         }
         return targets;
@@ -140,7 +139,7 @@
             ArrayList result = new ArrayList();
             for (int i = 0; i < targetList.length; i++) {
                 TargetImpl target = (TargetImpl) targetList[i];
-                ObjectName storeName = target.getObjectName();
+                AbstractName storeName = target.getAbstractName();
                 List infos = configurationManager.listConfigurations(storeName);
                 for (int j = 0; j < infos.size(); j++) {
                     ConfigurationInfo info = (ConfigurationInfo) infos.get(j);

Modified: geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/jmx/RemoteDeploymentManager.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/jmx/RemoteDeploymentManager.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/jmx/RemoteDeploymentManager.java (original)
+++ geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/jmx/RemoteDeploymentManager.java Thu Apr 13 23:30:38 2006
@@ -16,27 +16,35 @@
  */
 package org.apache.geronimo.deployment.plugin.jmx;
 
-import org.apache.geronimo.kernel.jmx.KernelDelegate;
-import org.apache.geronimo.deployment.plugin.local.DistributeCommand;
-import org.apache.geronimo.deployment.plugin.local.RedeployCommand;
-
-import javax.management.MBeanServerConnection;
-import javax.management.remote.JMXConnector;
-import javax.enterprise.deploy.spi.Target;
-import javax.enterprise.deploy.spi.TargetModuleID;
-import java.io.IOException;
 import java.io.File;
+import java.io.IOException;
 import java.io.InputStream;
 import java.net.InetAddress;
 import java.net.NetworkInterface;
+import java.net.URL;
 import java.util.Enumeration;
+import java.util.Iterator;
+import java.util.Set;
+import javax.enterprise.deploy.spi.Target;
+import javax.enterprise.deploy.spi.TargetModuleID;
+import javax.management.MBeanServerConnection;
+import javax.management.remote.JMXConnector;
+import org.apache.geronimo.deployment.plugin.GeronimoDeploymentManager;
+import org.apache.geronimo.deployment.plugin.local.DistributeCommand;
+import org.apache.geronimo.deployment.plugin.local.RedeployCommand;
+import org.apache.geronimo.gbean.AbstractName;
+import org.apache.geronimo.gbean.AbstractNameQuery;
+import org.apache.geronimo.kernel.jmx.KernelDelegate;
+import org.apache.geronimo.kernel.repository.Artifact;
+import org.apache.geronimo.system.configuration.ConfigurationMetadata;
+import org.apache.geronimo.system.configuration.DownloadResults;
 
 /**
  * Connects to a Kernel in a remote VM (may or many not be on the same machine).
  *
  * @version $Rev$ $Date$
  */
-public class RemoteDeploymentManager extends JMXDeploymentManager {
+public class RemoteDeploymentManager extends JMXDeploymentManager implements GeronimoDeploymentManager {
     private JMXConnector jmxConnector;
     private boolean isSameMachine;
 
@@ -115,5 +123,47 @@
         } else {
             return new org.apache.geronimo.deployment.plugin.remote.RedeployCommand(kernel, moduleIDList, moduleArchive, deploymentPlan);
         }
+    }
+
+    public ConfigurationMetadata[] listConfigurations(URL mavenRepository, String username, String password) throws IOException {
+        Set set = kernel.listGBeans(new AbstractNameQuery("org.apache.geronimo.system.configuration.ConfigurationInstaller"));
+        for (Iterator it = set.iterator(); it.hasNext();) {
+            AbstractName name = (AbstractName) it.next();
+            try {
+                return (ConfigurationMetadata[]) kernel.invoke(name, "listConfigurations", new Object[]{mavenRepository, username, password}, new String[]{URL.class.getName(), String.class.getName(), String.class.getName()});
+            } catch (Exception e) {
+                e.printStackTrace();
+                throw new IOException("Unable to list configurations: "+e.getMessage());
+            }
+        }
+        return null;
+    }
+
+    public ConfigurationMetadata loadDependencies(URL mavenRepository, String username, String password, ConfigurationMetadata source) throws IOException {
+        Set set = kernel.listGBeans(new AbstractNameQuery("org.apache.geronimo.system.configuration.ConfigurationInstaller"));
+        for (Iterator it = set.iterator(); it.hasNext();) {
+            AbstractName name = (AbstractName) it.next();
+            try {
+                return (ConfigurationMetadata) kernel.invoke(name, "loadDependencies", new Object[]{mavenRepository, username, password, source}, new String[]{URL.class.getName(), ConfigurationMetadata.class.getName(), String.class.getName(), String.class.getName()});
+            } catch (Exception e) {
+                e.printStackTrace();
+                throw new IOException("Unable to load dependencies: "+e.getMessage());
+            }
+        }
+        return null;
+    }
+
+    public DownloadResults install(URL mavenRepository, String username, String password, Artifact configId) throws IOException {
+        Set set = kernel.listGBeans(new AbstractNameQuery("org.apache.geronimo.system.configuration.ConfigurationInstaller"));
+        for (Iterator it = set.iterator(); it.hasNext();) {
+            AbstractName name = (AbstractName) it.next();
+            try {
+                return (DownloadResults) kernel.invoke(name, "install", new Object[]{mavenRepository, username, password, configId}, new String[]{URL.class.getName(), String.class.getName(), String.class.getName(), Artifact.class.getName()});
+            } catch (Exception e) {
+                e.printStackTrace();
+                throw new IOException("Unable to install configurations: "+e.getMessage());
+            }
+        }
+        return null;
     }
 }

Modified: geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/local/RedeployCommand.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/local/RedeployCommand.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/local/RedeployCommand.java (original)
+++ geronimo/branches/1.1/modules/deploy-jsr88/src/java/org/apache/geronimo/deployment/plugin/local/RedeployCommand.java Thu Apr 13 23:30:38 2006
@@ -25,6 +25,7 @@
 import org.apache.geronimo.kernel.config.ConfigurationManager;
 import org.apache.geronimo.kernel.config.ConfigurationUtil;
 import org.apache.geronimo.kernel.config.NoSuchConfigException;
+import org.apache.geronimo.gbean.AbstractName;
 
 import javax.enterprise.deploy.shared.CommandType;
 import javax.enterprise.deploy.spi.TargetModuleID;
@@ -98,7 +99,7 @@
                     }
 
                     TargetImpl target = (TargetImpl) module.getTarget();
-                    ObjectName storeName = target.getObjectName();
+                    AbstractName storeName = target.getAbstractName();
                     kernel.invoke(storeName, "uninstall", new Object[]{configID}, UNINSTALL_SIG);
                     updateStatus("Uninstalled "+configID);
 

Modified: geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/PluginBootstrap.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/PluginBootstrap.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/PluginBootstrap.java (original)
+++ geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/PluginBootstrap.java Thu Apr 13 23:30:38 2006
@@ -31,6 +31,8 @@
 import org.apache.geronimo.kernel.Jsr77Naming;
 import org.apache.geronimo.kernel.config.ConfigurationData;
 import org.apache.geronimo.kernel.config.ConfigurationStore;
+import org.apache.geronimo.kernel.config.NullConfigurationStore;
+import org.apache.geronimo.kernel.config.ConfigurationAlreadyExistsException;
 import org.apache.geronimo.kernel.repository.Artifact;
 import org.apache.geronimo.system.configuration.ExecutableConfigurationUtil;
 import org.apache.geronimo.system.repository.Maven1Repository;
@@ -70,39 +72,9 @@
 
         Maven1Repository repository = new Maven1Repository(localRepo);
         ServiceConfigBuilder builder = new ServiceConfigBuilder(null, Collections.singleton(repository), new Jsr77Naming());
-        ConfigurationStore targetConfigurationStore = new ConfigurationStore() {
-            public void install(ConfigurationData configurationData) {
-            }
-
-            public void uninstall(Artifact configID) {
-            }
-
-            public ConfigurationData loadConfiguration(Artifact configId) {
-                return null;
-            }
-
-            public boolean containsConfiguration(Artifact configID) {
-                return false;
-            }
-
-            public String getObjectName() {
-                return null;
-            }
-
-            public AbstractName getAbstractName() {
-                return null;
-            }
-
-            public List listConfigurations() {
-                return null;
-            }
-
-            public File createNewConfigurationDir(Artifact configId) {
+        ConfigurationStore targetConfigurationStore = new NullConfigurationStore() {
+            public File createNewConfigurationDir(Artifact configId) throws ConfigurationAlreadyExistsException {
                 return buildDir;
-            }
-
-            public URL resolve(Artifact configId, String moduleName, URI uri) {
-                return null;
             }
         };
 

Added: geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/cli/CommandListConfigurations.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/cli/CommandListConfigurations.java?rev=394030&view=auto
==============================================================================
--- geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/cli/CommandListConfigurations.java (added)
+++ geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/cli/CommandListConfigurations.java Thu Apr 13 23:30:38 2006
@@ -0,0 +1,132 @@
+/**
+ *
+ * Copyright 2005 The Apache Software Foundation
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
+package org.apache.geronimo.deployment.cli;
+
+import java.io.BufferedReader;
+import java.io.IOException;
+import java.io.InputStreamReader;
+import java.io.PrintWriter;
+import java.net.URL;
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import javax.enterprise.deploy.spi.DeploymentManager;
+import org.apache.geronimo.common.DeploymentException;
+import org.apache.geronimo.deployment.plugin.GeronimoDeploymentManager;
+import org.apache.geronimo.kernel.repository.Artifact;
+import org.apache.geronimo.system.configuration.ConfigurationMetadata;
+import org.apache.geronimo.system.configuration.DownloadResults;
+
+/**
+ * The CLI deployer logic to start.
+ *
+ * @version $Rev: 356097 $ $Date: 2005-12-11 20:29:03 -0500 (Sun, 11 Dec 2005) $
+ */
+public class CommandListConfigurations extends AbstractCommand {
+    public CommandListConfigurations() {
+        super("install-configs", "3. Geronimo Configurations", "MavenRepoURL",
+                "Lists the Geronimo configurations available in a Maven repository "+
+                "and lets you select configurations to download and install.  This "+
+                "is used to add new functionality to the Geronimo server.");
+    }
+
+    //todo: provide a way to handle a username and password for the remote repo?
+
+    public CommandListConfigurations(String command, String group, String helpArgumentList, String helpText) {
+        super(command, group, helpArgumentList, helpText);
+    }
+
+    public void execute(PrintWriter out, ServerConnection connection, String[] args) throws DeploymentException {
+        if(args.length == 0) {
+            throw new DeploymentSyntaxException("Must specify Maven repository URL");
+        }
+        DeploymentManager dmgr = connection.getDeploymentManager();
+        if(dmgr instanceof GeronimoDeploymentManager) {
+            GeronimoDeploymentManager mgr = (GeronimoDeploymentManager) dmgr;
+            ConfigurationMetadata[] data;
+            URL repository;
+            try {
+                repository = new URL(args[0]);
+                data = mgr.listConfigurations(repository, null, null);
+            } catch (IOException e) {
+                throw new DeploymentException("Unable to list configurations", e);
+            }
+            Map categories = new HashMap();
+            List available = new ArrayList();
+            for (int i = 0; i < data.length; i++) {
+                ConfigurationMetadata metadata = data[i];
+                List list = (List) categories.get(metadata.getCategory());
+                if(list == null) {
+                    list = new ArrayList();
+                    categories.put(metadata.getCategory(), list);
+                }
+                list.add(metadata);
+            }
+            for (Iterator it = categories.entrySet().iterator(); it.hasNext();) {
+                Map.Entry entry = (Map.Entry) it.next();
+                String category = (String) entry.getKey();
+                List items = (List) entry.getValue();
+                System.out.println();
+                System.out.print(DeployUtils.reformat(category, 4, 72));
+                for (int i = 0; i < items.size(); i++) {
+                    ConfigurationMetadata metadata = (ConfigurationMetadata) items.get(i);
+                    String prefix = "    ";
+                    if(!metadata.isInstalled() && metadata.isEligible()) {
+                        available.add(metadata);
+                        prefix = Integer.toString(available.size());
+                        if(available.size() < 10) {
+                            prefix += " ";
+                        }
+                        prefix += ": ";
+                    }
+                    System.out.print(DeployUtils.reformat(prefix+metadata.getDescription()+" ("+metadata.getVersion()+")", 8, 72));
+                    System.out.flush();
+                }
+            }
+            System.out.println();
+            System.out.print("Install Service [enter number or 'q' to quit]: ");
+            System.out.flush();
+            try {
+                BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
+                String answer = in.readLine();
+                if(answer.equalsIgnoreCase("q")) {
+                    return;
+                }
+                int selection = Integer.parseInt(answer);
+                ConfigurationMetadata target = ((ConfigurationMetadata) available.get(selection - 1));
+                DownloadResults results = mgr.install(repository, null, null, target.getConfigId());
+                for (int i = 0; i < results.getDependenciesPresent().length; i++) {
+                    Artifact uri = results.getDependenciesPresent()[i];
+                    System.out.print(DeployUtils.reformat("Using existing dependency "+uri, 4, 72));
+                }
+                for (int i = 0; i < results.getDependenciesInstalled().length; i++) {
+                    Artifact uri = results.getDependenciesInstalled()[i];
+                    System.out.print(DeployUtils.reformat("Installed new dependency "+uri, 4, 72));
+                }
+                new CommandStart().execute(out, connection, new String[]{target.getConfigId().toString()});
+            } catch (IOException e) {
+                throw new DeploymentException("Unable to install configuration", e);
+            } catch(NumberFormatException e) {
+                throw new DeploymentException("Invalid response");
+            }
+        } else {
+            throw new DeploymentException("Cannot list repositories when connected to "+connection.getServerURI());
+        }
+    }
+}

Propchange: geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/cli/CommandListConfigurations.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/cli/DeployTool.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/cli/DeployTool.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/cli/DeployTool.java (original)
+++ geronimo/branches/1.1/modules/deploy-tool/src/java/org/apache/geronimo/deployment/cli/DeployTool.java Thu Apr 13 23:30:38 2006
@@ -74,6 +74,7 @@
         registerCommand(new CommandStart());
         registerCommand(new CommandStop());
         registerCommand(new CommandUndeploy());
+        registerCommand(new CommandListConfigurations());
     }
 
     private boolean failed = false;

Modified: geronimo/branches/1.1/modules/j2ee-builder/src/test/org/apache/geronimo/j2ee/deployment/EARConfigBuilderTest.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/j2ee-builder/src/test/org/apache/geronimo/j2ee/deployment/EARConfigBuilderTest.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/j2ee-builder/src/test/org/apache/geronimo/j2ee/deployment/EARConfigBuilderTest.java (original)
+++ geronimo/branches/1.1/modules/j2ee-builder/src/test/org/apache/geronimo/j2ee/deployment/EARConfigBuilderTest.java Thu Apr 13 23:30:38 2006
@@ -45,6 +45,7 @@
 import org.apache.geronimo.kernel.config.ConfigurationStore;
 import org.apache.geronimo.kernel.config.InvalidConfigException;
 import org.apache.geronimo.kernel.config.NoSuchConfigException;
+import org.apache.geronimo.kernel.config.NullConfigurationStore;
 import org.apache.geronimo.kernel.repository.Artifact;
 import org.apache.geronimo.kernel.repository.Environment;
 import org.apache.geronimo.kernel.repository.ImportType;
@@ -551,15 +552,9 @@
         }
     }
 
-    public static class MockConfigStore implements ConfigurationStore {
+    public static class MockConfigStore extends NullConfigurationStore {
         private final Map locations = new HashMap();
 
-        public void install(ConfigurationData configurationData) throws IOException, InvalidConfigException {
-        }
-
-        public void uninstall(Artifact configID) throws NoSuchConfigException, IOException {
-        }
-
         public ConfigurationData loadConfiguration(Artifact configId) throws NoSuchConfigException, IOException, InvalidConfigException {
             ConfigurationData configurationData = new ConfigurationData(configId, naming);
             configurationData.setConfigurationStore(this);
@@ -568,18 +563,6 @@
 
         public boolean containsConfiguration(Artifact configID) {
             return true;
-        }
-
-        public String getObjectName() {
-            return null;
-        }
-
-        public AbstractName getAbstractName() {
-            return null;
-        }
-
-        public List listConfigurations() {
-            return null;
         }
 
         public File createNewConfigurationDir(Artifact configId) {

Modified: geronimo/branches/1.1/modules/j2ee/src/java/org/apache/geronimo/j2ee/management/impl/J2EEServerImpl.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/j2ee/src/java/org/apache/geronimo/j2ee/management/impl/J2EEServerImpl.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/j2ee/src/java/org/apache/geronimo/j2ee/management/impl/J2EEServerImpl.java (original)
+++ geronimo/branches/1.1/modules/j2ee/src/java/org/apache/geronimo/j2ee/management/impl/J2EEServerImpl.java Thu Apr 13 23:30:38 2006
@@ -28,6 +28,8 @@
 import org.apache.geronimo.gbean.GBeanInfoBuilder;
 import org.apache.geronimo.j2ee.j2eeobjectnames.NameFactory;
 import org.apache.geronimo.kernel.Kernel;
+import org.apache.geronimo.kernel.config.ConfigurationManager;
+import org.apache.geronimo.kernel.config.ConfigurationUtil;
 import org.apache.geronimo.kernel.jmx.JMXUtil;
 import org.apache.geronimo.kernel.proxy.ProxyManager;
 import org.apache.geronimo.kernel.repository.Repository;
@@ -43,6 +45,7 @@
 import org.apache.geronimo.management.geronimo.WebManager;
 import org.apache.geronimo.management.geronimo.KeystoreManager;
 import org.apache.geronimo.system.serverinfo.ServerInfo;
+import org.apache.geronimo.system.configuration.ConfigurationInstaller;
 
 /**
  * @version $Rev$ $Date$
@@ -170,6 +173,14 @@
 
     public KeystoreManager getKeystoreManager() {
         return (KeystoreManager) getObject(KeystoreManager.class);
+    }
+
+    public ConfigurationInstaller getConfigurationInstaller() {
+        return (ConfigurationInstaller) getObject(ConfigurationInstaller.class);
+    }
+
+    public ConfigurationManager getConfigurationManager() {
+        return ConfigurationUtil.getConfigurationManager(kernel);
     }
 
     public String getServerVendor() {

Modified: geronimo/branches/1.1/modules/jetty-builder/src/test/org/apache/geronimo/jetty/deployment/JettyModuleBuilderTest.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/jetty-builder/src/test/org/apache/geronimo/jetty/deployment/JettyModuleBuilderTest.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/jetty-builder/src/test/org/apache/geronimo/jetty/deployment/JettyModuleBuilderTest.java (original)
+++ geronimo/branches/1.1/modules/jetty-builder/src/test/org/apache/geronimo/jetty/deployment/JettyModuleBuilderTest.java Thu Apr 13 23:30:38 2006
@@ -69,6 +69,7 @@
 import org.apache.geronimo.kernel.config.EditableKernelConfigurationManager;
 import org.apache.geronimo.kernel.config.InvalidConfigException;
 import org.apache.geronimo.kernel.config.NoSuchConfigException;
+import org.apache.geronimo.kernel.config.NullConfigurationStore;
 import org.apache.geronimo.kernel.management.State;
 import org.apache.geronimo.kernel.repository.Artifact;
 import org.apache.geronimo.kernel.repository.DefaultArtifactManager;
@@ -286,7 +287,7 @@
     }
 
 
-    public static class MockConfigStore implements ConfigurationStore {
+    public static class MockConfigStore extends NullConfigurationStore {
         private Map configs = new HashMap();
 
         URL baseURL;
@@ -320,18 +321,6 @@
 
         public boolean containsConfiguration(Artifact configID) {
             return true;
-        }
-
-        public String getObjectName() {
-            return null;
-        }
-
-        public AbstractName getAbstractName() {
-            return null;
-        }
-
-        public List listConfigurations() {
-            return null;
         }
 
         public File createNewConfigurationDir(Artifact configId) {

Modified: geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/JettyManagerImpl.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/JettyManagerImpl.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/JettyManagerImpl.java (original)
+++ geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/JettyManagerImpl.java Thu Apr 13 23:30:38 2006
@@ -16,13 +16,19 @@
  */
 package org.apache.geronimo.jetty;
 
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.geronimo.gbean.AbstractName;
+import org.apache.geronimo.gbean.AbstractNameQuery;
 import org.apache.geronimo.gbean.GBeanData;
 import org.apache.geronimo.gbean.GBeanInfo;
 import org.apache.geronimo.gbean.GBeanInfoBuilder;
-import org.apache.geronimo.gbean.AbstractName;
-import org.apache.geronimo.gbean.AbstractNameQuery;
 import org.apache.geronimo.gbean.ReferencePatterns;
 import org.apache.geronimo.j2ee.j2eeobjectnames.NameFactory;
 import org.apache.geronimo.jetty.connector.AJP13Connector;
@@ -32,23 +38,16 @@
 import org.apache.geronimo.jetty.requestlog.JettyLogManager;
 import org.apache.geronimo.kernel.GBeanNotFoundException;
 import org.apache.geronimo.kernel.Kernel;
-import org.apache.geronimo.kernel.proxy.ProxyManager;
 import org.apache.geronimo.kernel.config.ConfigurationUtil;
 import org.apache.geronimo.kernel.config.EditableConfigurationManager;
 import org.apache.geronimo.kernel.config.InvalidConfigException;
-import org.apache.geronimo.management.geronimo.WebManager;
+import org.apache.geronimo.kernel.proxy.ProxyManager;
+import org.apache.geronimo.management.geronimo.KeystoreManager;
 import org.apache.geronimo.management.geronimo.NetworkConnector;
+import org.apache.geronimo.management.geronimo.WebAccessLog;
 import org.apache.geronimo.management.geronimo.WebConnector;
 import org.apache.geronimo.management.geronimo.WebContainer;
-import org.apache.geronimo.management.geronimo.WebAccessLog;
-
-import java.util.ArrayList;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Set;
-import java.util.Collections;
-import java.util.Map;
-import java.util.HashMap;
+import org.apache.geronimo.management.geronimo.WebManager;
 
 /**
  * Jetty implementation of WebManager.  Knows how to manipulate
@@ -81,8 +80,8 @@
             connector = new GBeanData(name, HTTPConnector.GBEAN_INFO);
         } else if (protocol.equals(PROTOCOL_HTTPS)) {
             connector = new GBeanData(name, HTTPSConnector.GBEAN_INFO);
-            AbstractNameQuery query = new AbstractNameQuery(null, Collections.singletonMap(NameFactory.J2EE_TYPE, "ServerInfo"));
-            connector.setReferencePattern("ServerInfo", query);
+            AbstractNameQuery query = new AbstractNameQuery(KeystoreManager.class.getName());
+            connector.setReferencePattern("KeystoreManager", query);
             //todo: default HTTPS settings
         } else if (protocol.equals(PROTOCOL_AJP)) {
             connector = new GBeanData(name, AJP13Connector.GBEAN_INFO);

Modified: geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/JettySecureConnector.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/JettySecureConnector.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/JettySecureConnector.java (original)
+++ geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/JettySecureConnector.java Thu Apr 13 23:30:38 2006
@@ -22,9 +22,9 @@
  * @version $Rev$ $Date$
  */
 public interface JettySecureConnector extends SecureConnector {
-    /**
-     * Sets the password used to access the server private key inside the
-     * keystore.
-     */
-    public void setKeyPassword(String password);
+    public void setKeyStore(String keyStore);
+
+    public void setTrustStore(String trustStore);
+
+    public void setKeyAlias(String keyAlias);
 }

Copied: geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/connector/GeronimoSSLListener.java (from r389206, geronimo/trunk/modules/jetty/src/java/org/apache/geronimo/jetty/connector/GeronimoSSLListener.java)
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/connector/GeronimoSSLListener.java?p2=geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/connector/GeronimoSSLListener.java&p1=geronimo/trunk/modules/jetty/src/java/org/apache/geronimo/jetty/connector/GeronimoSSLListener.java&r1=389206&r2=394030&rev=394030&view=diff
==============================================================================
--- geronimo/trunk/modules/jetty/src/java/org/apache/geronimo/jetty/connector/GeronimoSSLListener.java (original)
+++ geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/connector/GeronimoSSLListener.java Thu Apr 13 23:30:38 2006
@@ -17,7 +17,7 @@
 package org.apache.geronimo.jetty.connector;
 
 import org.mortbay.http.SslListener;
-import org.apache.geronimo.security.keystore.KeystoreManager;
+import org.apache.geronimo.management.geronimo.KeystoreManager;
 
 import javax.net.ssl.SSLServerSocketFactory;
 

Modified: geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/connector/HTTPSConnector.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/connector/HTTPSConnector.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/connector/HTTPSConnector.java (original)
+++ geronimo/branches/1.1/modules/jetty/src/java/org/apache/geronimo/jetty/connector/HTTPSConnector.java Thu Apr 13 23:30:38 2006
@@ -18,16 +18,13 @@
 package org.apache.geronimo.jetty.connector;
 
 import javax.net.ssl.KeyManagerFactory;
-
-import org.mortbay.http.SslListener;
-
 import org.apache.geronimo.gbean.GBeanInfo;
 import org.apache.geronimo.gbean.GBeanInfoBuilder;
 import org.apache.geronimo.j2ee.j2eeobjectnames.NameFactory;
-import org.apache.geronimo.management.geronimo.WebManager;
 import org.apache.geronimo.jetty.JettyContainer;
 import org.apache.geronimo.jetty.JettySecureConnector;
-import org.apache.geronimo.system.serverinfo.ServerInfo;
+import org.apache.geronimo.management.geronimo.KeystoreManager;
+import org.apache.geronimo.management.geronimo.WebManager;
 
 /**
  * Implementation of a HTTPS connector based on Jetty's SslConnector (which uses pure JSSE).
@@ -35,15 +32,12 @@
  * @version $Rev$ $Date$
  */
 public class HTTPSConnector extends JettyConnector implements JettySecureConnector {
-    private final SslListener https;
-    private final ServerInfo serverInfo;
-    private String keystore;
+    private final GeronimoSSLListener https;
     private String algorithm;
 
-    public HTTPSConnector(JettyContainer container, ServerInfo serverInfo) {
-        super(container, new SslListener());
-        this.serverInfo = serverInfo;
-        https = (SslListener) listener;
+    public HTTPSConnector(JettyContainer container, KeystoreManager keystoreManager) {
+        super(container, new GeronimoSSLListener(keystoreManager));
+        https = (GeronimoSSLListener) listener;
     }
 
     public int getDefaultPort() {
@@ -54,16 +48,6 @@
         return WebManager.PROTOCOL_HTTPS;
     }
 
-    public String getKeystoreFileName() {
-        // this does not delegate to https as it needs to be resolved against ServerInfo
-        return keystore;
-    }
-
-    public void setKeystoreFileName(String keystore) {
-        // this does not delegate to https as it needs to be resolved against ServerInfo
-        this.keystore = keystore;
-    }
-
     public String getAlgorithm() {
         return algorithm;
     }
@@ -83,14 +67,6 @@
         https.setAlgorithm(algorithm);
     }
 
-    public void setKeystorePassword(String password) {
-        https.setPassword(password);
-    }
-
-    public void setKeyPassword(String password) {
-        https.setKeyPassword(password);
-    }
-
     public String getSecureProtocol() {
         return https.getProtocol();
     }
@@ -99,14 +75,6 @@
         https.setProtocol(protocol);
     }
 
-    public String getKeystoreType() {
-        return https.getKeystoreType();
-    }
-
-    public void setKeystoreType(String keystoreType) {
-        https.setKeystoreType(keystoreType);
-    }
-
     public void setClientAuthRequired(boolean needClientAuth) {
         https.setNeedClientAuth(needClientAuth);
     }
@@ -123,30 +91,68 @@
         return https.getWantClientAuth();
     }
 
-    public void doStart() throws Exception {
-        https.setKeystore(serverInfo.resolvePath(keystore));
-        super.doStart();
+    public void setKeyStore(String keyStore) {
+        https.setKeyStore(keyStore);
+    }
+
+    public String getKeyStore() {
+        return https.getKeyStore();
+    }
+
+    public void setTrustStore(String trustStore) {
+        https.setTrustStore(trustStore);
+    }
+
+    public String getTrustStore() {
+        return https.getTrustStore();
+    }
+
+    public void setKeyAlias(String keyAlias) {
+        https.setKeyAlias(keyAlias);
+    }
+
+    public String getKeyAlias() {
+        return https.getKeyAlias();
     }
 
     public static final GBeanInfo GBEAN_INFO;
 
     static {
         GBeanInfoBuilder infoFactory = GBeanInfoBuilder.createStatic("Jetty Connector HTTPS", HTTPSConnector.class, JettyConnector.GBEAN_INFO);
-        infoFactory.addAttribute("keystoreFileName", String.class, true, true);
         infoFactory.addAttribute("algorithm", String.class, true, true);
-        infoFactory.addAttribute("keystorePassword", String.class, true, true);
-        infoFactory.addAttribute("keyPassword", String.class, true, true);
         infoFactory.addAttribute("secureProtocol", String.class, true, true);
-        infoFactory.addAttribute("keystoreType", String.class, true, true);
+        infoFactory.addAttribute("keyStore", String.class, true, true);
+        infoFactory.addAttribute("keyAlias", String.class, true, true);
+        infoFactory.addAttribute("trustStore", String.class, true, true);
         infoFactory.addAttribute("clientAuthRequired", boolean.class, true, true);
         infoFactory.addAttribute("clientAuthRequested", boolean.class, true, true);
-        infoFactory.addReference("ServerInfo", ServerInfo.class, NameFactory.GERONIMO_SERVICE);
+        infoFactory.addReference("KeystoreManager", KeystoreManager.class, NameFactory.GERONIMO_SERVICE);
         infoFactory.addInterface(JettySecureConnector.class);
-        infoFactory.setConstructor(new String[]{"JettyContainer", "ServerInfo"});
+        infoFactory.setConstructor(new String[]{"JettyContainer", "KeystoreManager"});
         GBEAN_INFO = infoFactory.getBeanInfo();
     }
 
     public static GBeanInfo getGBeanInfo() {
         return GBEAN_INFO;
+    }
+
+    // ================= NO LONGER USED!!! =====================
+    // todo: remove these from the SSL interface
+
+    public String getKeystoreFileName() {
+        return null;
+    }
+
+    public void setKeystoreFileName(String name) {
+    }
+
+    public void setKeystorePassword(String password) {
+    }
+
+    public String getKeystoreType() {
+        return null;
+    }
+
+    public void setKeystoreType(String type) {
     }
 }

Modified: geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/ConfigurationManager.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/ConfigurationManager.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/ConfigurationManager.java (original)
+++ geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/ConfigurationManager.java Thu Apr 13 23:30:38 2006
@@ -20,6 +20,7 @@
 import java.util.List;
 import javax.management.ObjectName;
 import org.apache.geronimo.kernel.repository.Artifact;
+import org.apache.geronimo.gbean.AbstractName;
 
 /**
  * Encapsulates logic for dealing with configurations.
@@ -29,18 +30,25 @@
 public interface ConfigurationManager {
     /**
      * Is the specified configuration loaded into the kernel?
+     *
      * @param configID the name of the configuration
+     *
      * @return true if the configuration has been loaded; false otherwise
      */
     boolean isLoaded(Artifact configID);
 
     /**
      * Return a list of the stores this manager knows about.
-     * @return a List<AbstractName> of the stores this manager controls
+     * @return a List (with elements of type AbstractName) of the stores this manager controls
      */
     List listStores();
 
     /**
+     * Get all the ConfigurationStores known to this manager at present
+     */
+    ConfigurationStore[] getStores();
+
+    /**
      * Gets the configuration store responsible for the specified
      * configuration, or null if there is none.
      */
@@ -48,69 +56,45 @@
 
     /**
      * Return a list of the configurations in a specific store.
+     *
      * @param store the store to list
-     * @return a List<ConfigurationInfo> of all the configurations in the store
+     *
+     * @return a List (with elements of type ConfigurationInfo) of all the configurations in the store
+     *
      * @throws NoSuchStoreException if the store could not be located
-     * @deprecated Find a better way.... hopefully we can just use the listConfiguration with no name or the name can be an AbstractName
      */
-    List listConfigurations(ObjectName store) throws NoSuchStoreException;
+    List listConfigurations(AbstractName store) throws NoSuchStoreException;
 
     /**
-     * Is the specified artifact a configurations?
+     * Is the specified artifact a configuration that has been loaded in the kernel?
+     *
      * @param artifact the artifact to check
-     * @return true if the artifact is a configuration
+     *
+     * @return true if the artifact is a configuration and has been loaded
      */
     boolean isConfiguration(Artifact artifact);
 
     /**
-     * Gets the loaded Configuration.
+     * Gets a loaded Configuration (does not see unloaded configurations).
+     *
      * @param configId the configuration to get
+     *
      * @return the specified configuration or null if the configuration has not been loaded
      */
     Configuration getConfiguration(Artifact configId);
 
-    /**
-     * Load the specified configuration and all parent configurations into the kernel. This does not
-     * start any configuration gbeans or load any gbeans from the configurations loaded.  It does
-     * not hurt to call this even if some or all of the GBeans are already loaded -- though only
-     * configurations actually loaded by this call will be returned.
-     *
-     * @param configID the id of the configuration
-     * @throws NoSuchConfigException if no configuration with the given id exists in the configuration stores
-     * @throws IOException if there is a problem loading te configuration from the store
-     * @throws InvalidConfigException if the configuration is corrupt
-     */
     void loadConfiguration(Artifact configID) throws NoSuchConfigException, IOException, InvalidConfigException;
 
     Configuration loadConfiguration(ConfigurationData configurationData) throws NoSuchConfigException, IOException, InvalidConfigException;
 
-    /**
-     * Unloads the gbeans of the specified configuration, stops the configuration gbean, and unloads the
-     * configuration gbean from the kernel.  Stop should always be called first.
-     *
-     * @param configID the name fo the configuration to remove
-     * @throws NoSuchConfigException if the configuration is now loaded into the kernel
-     */
     void unloadConfiguration(Artifact configID) throws NoSuchConfigException;
 
     void unloadConfiguration(Configuration configuration) throws NoSuchConfigException;
 
-    /**
-     * Start the gbeans in this configuration.  
-     *
-     * @param configID
-     * @throws InvalidConfigException
-     */
     void startConfiguration(Artifact configID) throws InvalidConfigException;
 
     void startConfiguration(Configuration configuration) throws InvalidConfigException;
 
-    /**
-     * Stop the gbeans in this configuration, but do not stop the configuration gbean.
-     *
-     * @param configID
-     * @throws InvalidConfigException
-     */
     void stopConfiguration(Artifact configID) throws NoSuchConfigException;
 
     void stopConfiguration(Configuration configuration) throws NoSuchConfigException;

Modified: geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/ConfigurationStore.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/ConfigurationStore.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/NullConfigurationStore.java (added)
+++ geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/NullConfigurationStore.java Thu Apr 13 23:30:38 2006
@@ -0,0 +1,72 @@
+/**
+ *
+ * Copyright 2005 The Apache Software Foundation
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
+package org.apache.geronimo.kernel.config;
+
+import org.apache.geronimo.kernel.repository.Artifact;
+import org.apache.geronimo.gbean.AbstractName;
+
+import java.io.IOException;
+import java.io.File;
+import java.io.OutputStream;
+import java.util.List;
+import java.net.URL;
+import java.net.URI;
+import java.net.MalformedURLException;
+
+/**
+ * A non-functional configuration store that can be extended to be useful.
+ *
+ * @version $Rev: 46019 $ $Date: 2004-09-14 05:56:06 -0400 (Tue, 14 Sep 2004) $
+ */
+public class NullConfigurationStore implements ConfigurationStore {
+    public void install(ConfigurationData configurationData) throws IOException, InvalidConfigException {
+    }
+
+    public void uninstall(Artifact configId) throws NoSuchConfigException, IOException {
+    }
+
+    public ConfigurationData loadConfiguration(Artifact configId) throws NoSuchConfigException, IOException, InvalidConfigException {
+        return null;
+    }
+
+    public boolean containsConfiguration(Artifact configId) {
+        return false;
+    }
+
+    public String getObjectName() {
+        return null;
+    }
+
+    public AbstractName getAbstractName() {
+        return null;
+    }
+
+    public List listConfigurations() {
+        return null;
+    }
+
+    public File createNewConfigurationDir(Artifact configId) throws ConfigurationAlreadyExistsException {
+        return null;
+    }
+
+    public URL resolve(Artifact configId, String moduleName, URI uri) throws NoSuchConfigException, MalformedURLException {
+        return null;
+    }
+
+    public void exportConfiguration(Artifact configId, OutputStream output) throws IOException, NoSuchConfigException {
+    }
+}

Propchange: geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/NullConfigurationStore.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/SimpleConfigurationManager.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/SimpleConfigurationManager.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/SimpleConfigurationManager.java (original)
+++ geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/SimpleConfigurationManager.java Thu Apr 13 23:30:38 2006
@@ -31,6 +31,7 @@
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.geronimo.gbean.InvalidConfigurationException;
+import org.apache.geronimo.gbean.AbstractName;
 import org.apache.geronimo.kernel.jmx.JMXUtil;
 import org.apache.geronimo.kernel.management.State;
 import org.apache.geronimo.kernel.repository.Artifact;
@@ -60,17 +61,23 @@
     }
 
     public List listStores() {
-        List storeSnapshot = getStores();
+        List storeSnapshot = getStoreList();
         List result = new ArrayList(storeSnapshot.size());
         for (int i = 0; i < storeSnapshot.size(); i++) {
             ConfigurationStore store = (ConfigurationStore) storeSnapshot.get(i);
-            result.add(JMXUtil.getObjectName(store.getObjectName()));
+            result.add(store.getAbstractName());
         }
         return result;
     }
 
+    public ConfigurationStore[] getStores() {
+        List storeSnapshot = getStoreList();
+        return (ConfigurationStore[]) storeSnapshot.toArray(new ConfigurationStore[storeSnapshot.size()]);
+    }
+
+
     public List listConfigurations() {
-        List storeSnapshot = getStores();
+        List storeSnapshot = getStoreList();
         List list = new ArrayList();
         for (int i = 0; i < storeSnapshot.size(); i++) {
             ConfigurationStore store = (ConfigurationStore) storeSnapshot.get(i);
@@ -80,7 +87,7 @@
     }
 
     public ConfigurationStore getStoreForConfiguration(Artifact configuration) {
-        List storeSnapshot = getStores();
+        List storeSnapshot = getStoreList();
         for (int i = 0; i < storeSnapshot.size(); i++) {
             ConfigurationStore store = (ConfigurationStore) storeSnapshot.get(i);
             if(store.containsConfiguration(configuration)) {
@@ -90,11 +97,11 @@
         return null;
     }
 
-    public List listConfigurations(ObjectName storeName) throws NoSuchStoreException {
-        List storeSnapshot = getStores();
+    public List listConfigurations(AbstractName storeName) throws NoSuchStoreException {
+        List storeSnapshot = getStoreList();
         for (int i = 0; i < storeSnapshot.size(); i++) {
             ConfigurationStore store = (ConfigurationStore) storeSnapshot.get(i);
-            if (storeName.equals(JMXUtil.getObjectName(store.getObjectName()))) {
+            if (storeName.equals(store.getAbstractName())) {
                 return listConfigurations(store);
             }
         }
@@ -129,7 +136,7 @@
             return true;
         }
 
-        List storeSnapshot = getStores();
+        List storeSnapshot = getStoreList();
         for (int i = 0; i < storeSnapshot.size(); i++) {
             ConfigurationStore store = (ConfigurationStore) storeSnapshot.get(i);
             if (store.containsConfiguration(artifact)) {
@@ -306,7 +313,7 @@
     }
 
     private ConfigurationData loadConfigurationGBeanData(Artifact configId) throws NoSuchConfigException, IOException, InvalidConfigException {
-        List storeSnapshot = getStores();
+        List storeSnapshot = getStoreList();
 
         for (int i = 0; i < storeSnapshot.size(); i++) {
             ConfigurationStore store = (ConfigurationStore) storeSnapshot.get(i);
@@ -459,7 +466,7 @@
             unloadConfiguration(configurationStatus);
         }
 
-        List storeSnapshot = getStores();
+        List storeSnapshot = getStoreList();
         for (int i = 0; i < storeSnapshot.size(); i++) {
             ConfigurationStore store = (ConfigurationStore) storeSnapshot.get(i);
             if(store.containsConfiguration(configId)) {
@@ -469,7 +476,7 @@
 
     }
 
-    private List getStores() {
+    private List getStoreList() {
         return new ArrayList(stores);
     }
 

Modified: geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/repository/Dependency.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/repository/Dependency.java?rev=394030&r1=394029&r2=394030&view=diff
==============================================================================
--- geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/repository/Dependency.java (original)
+++ geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/repository/Dependency.java Thu Apr 13 23:30:38 2006
@@ -19,6 +19,10 @@
 import java.io.Serializable;
 
 /**
+ * A dependency of a Geronimo configuration.  This may be another
+ * configuration, or it may be a third-party JAR that just needs to go on the
+ * configuration Class Path.
+ *
  * @version $Rev$ $Date$
  */
 public class Dependency implements Serializable {
--- geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/ConfigurationStore.java (original)
+++ geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/ConfigurationStore.java Thu Apr 13 23:30:38 2006
@@ -19,6 +19,7 @@
 
 import java.io.File;
 import java.io.IOException;
+import java.io.OutputStream;
 import java.net.MalformedURLException;
 import java.net.URI;
 import java.net.URL;
@@ -91,18 +92,31 @@
 
     /**
      * Creates an empty diretory for a new configuration with the specified configId
+     *
      * @param configId the unique ID of the configuration
+     *
      * @return the location of the new directory
+     * 
      * @throws ConfigurationAlreadyExistsException if the configuration already exists in this store
      */
     File createNewConfigurationDir(Artifact configId) throws ConfigurationAlreadyExistsException;
 
     /**
      * Locate the classpath component for the supplied uri in the given artifact
      * @param configId
      * @param moduleName
      * @param uri
      * @return URL for the configuration component.
      */
     URL resolve(Artifact configId, String moduleName, URI uri) throws NoSuchConfigException, MalformedURLException;
+
+    /**
+     * Exports a configuration as a ZIP file
+     *
+     * @param configId  The configuration to export
+     * @param output    The stream to write the ZIP content to
+     */
+    void exportConfiguration(Artifact configId, OutputStream output) throws IOException, NoSuchConfigException;
 }
@@ -91,18 +92,31 @@
     /**
      * Locate the classpath component for the supplied uri in the given artifact
-     * @param configId
-     * @param moduleName
-     * @param uri
+     *
+     * @param configId    Identifies the configuration that the resource is in
+     * @param moduleName  The module within the configuration that contains the resource
+     * @param uri         The path to the resource within the module
+     *
      * @return URL for the configuration component.
      */

Added: geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/NullConfigurationStore.java
URL: http://svn.apache.org/viewcvs/geronimo/branches/1.1/modules/kernel/src/java/org/apache/geronimo/kernel/config/NullConfigurationStore.java?rev=394030&view=auto
==============================================================================